@@ -99,9 +99,14 @@ class QueryBuilder(BaseView):
         if not empty_query:
             if search_with_solr:
                 if "SearchableText" in parsedquery:
-                    parsedquery["SearchableText"] = parsedquery[
-                        "SearchableText"
-                    ].rstrip("*")
+                    if isinstance(parsedquery["SearchableText"], dict):
+                        parsedquery["SearchableText"]["query"] = parsedquery[
+                            "SearchableText"
+                        ]["query"].rstrip("*")
+                    else:
+                        parsedquery["SearchableText"] = parsedquery[
+                            "SearchableText"
+                        ].rstrip("*")
                 results = SolrResponse(
                     data=solr_search(
                         **self.clean_query_for_solr(query=parsedquery)
@@ -127,8 +132,7 @@ class QueryBuilder(BaseView):
         filtered_sites = []
         for k, v in query.items():
             if k == "sort_on":
-                v = SORT_ON_MAPPING.get(v, v)
-                fixed_query[k] = v
+                fixed_query[k] = SORT_ON_MAPPING.get(v, v)
             elif k == "path":
                 portal_state = api.content.get_view(
                     context=self.context,
@@ -149,6 +153,9 @@ class QueryBuilder(BaseView):
             elif k == "solr_subjects":
                 fixed_query["Subject"] = self.extract_value(v)
                 continue
+            elif k == "solr_portal_types":
+                fixed_query["portal_type"] = self.extract_value(v)
+                continue
             else:
                 fixed_query[k] = v
             if filtered_sites:
