@@ -9,6 +9,9 @@ from rer.solrpush.utils.solr_common import get_index_fields
 from rer.solrpush.interfaces.settings import IRerSolrpushSettings
 from rer.solrpush.utils.solr_indexer import parse_date_str
 from DateTime import DateTime
+from pysolr import safe_urlencode
+from zope.annotation.interfaces import IAnnotations
+from zope.globalrequest import getRequest
 
 import logging
 import json
@@ -89,7 +92,10 @@ def set_sort_parameter(query):
 
 
 def generate_query(
-    query, fl=None, facets=False, facet_fields=["Subject", "portal_type"],
+    query,
+    fl=None,
+    facets=False,
+    facet_fields=["Subject", "portal_type"],
 ):
     solr_query = {
         "q": "",
@@ -108,6 +114,7 @@ def generate_query(
     if facets:
         solr_query["facet.field"] = facet_fields
         solr_query["facet.mincount"] = 1
+        solr_query["facet.limit"] = -1
     if fl:
         if "UID" not in fl:
             # we need it because if we ask for [elevated] value, solr returns
@@ -294,9 +301,13 @@ def search(
             ),
         }
     solr_query = generate_query(
-        query, fl=fl, facets=facets, facet_fields=facet_fields,
+        query,
+        fl=fl,
+        facets=facets,
+        facet_fields=facet_fields,
     )
     try:
+        _set_query_debug(solr=solr, params=solr_query)
         res = solr.search(**solr_query)
         return res
     except Exception as e:
@@ -313,3 +324,22 @@ def search(
                 context=api.portal.get().REQUEST,
             ),
         }
+
+
+def _set_query_debug(solr, params):
+    try:
+        if not get_setting(
+            field="query_debug", interface=IRerSolrpushSettings
+        ):
+            return
+    except KeyError:
+        # key not available: do not save data
+        return
+    request = getRequest()
+    annotations = IAnnotations(request)
+    annotations["solr_query"] = {
+        "url": "{url}/select?{params}".format(
+            url=solr.url, params=safe_urlencode(params, True)
+        ),
+        "params": params,
+    }
